@@ -34,7 +34,8 @@ ClassificationAlgorithm <- R6::R6Class("ClassificationAlgorithm",
       private$testDataset <- test
 
       #Test jar file
-      if(! file.exists(paste0(private$exePath, private$jarName))){
+      #if(! file.exists(paste0(private$exePath, private$jarName))){
+      if(! file.exists(system.file("exe", private$jarName, package = "RKEELjars"))){
         stop(paste0(private$jarName, " doesn't exist under the defined path. Installation error."))
       }
 
@@ -68,7 +69,7 @@ ClassificationAlgorithm <- R6::R6Class("ClassificationAlgorithm",
         #file.copy(paste0(private$dataPath, private$testFilename), paste0(private$mainPath, "/datasets/", private$dataName, "/", private$testFilename))
 
         #Copy algorithm exe
-        file.copy(paste0(private$exePath, private$jarName), paste0(private$mainPath, "/exe/", private$jarName))
+        file.copy(system.file("exe", private$jarName, package = "RKEELjars"), paste0(private$mainPath, "/exe/", private$jarName))
 
         #Create results dir
         dir.create(paste0(private$mainPath, "/results/", private$algorithmName, ".", private$dataName))
@@ -231,7 +232,7 @@ ClassificationAlgorithm <- R6::R6Class("ClassificationAlgorithm",
         i <- i-1
       }
       #Obtain class names
-      classes <- trimws(strsplit(strsplit(strsplit(text[i], "{", fixed = TRUE)[[1]][2], "}", fixed=TRUE)[[1]][1], ",", fixed=TRUE)[[1]])
+      classes <- gdata::trim(strsplit(strsplit(strsplit(text[i], "{", fixed = TRUE)[[1]][2], "}", fixed=TRUE)[[1]][1], ",", fixed=TRUE)[[1]])
 
       while(text[i] != "@data"){
         i <- i+1
